#
# These are the definitions for doc2lt and doctext HTML output
#
# Doc2lt single line entry
preamble   
postamble  %n
key        %n\k{%1}
definition \DeFn{%1}}%n
synopsis   {\CoDe{%N="\\"%1%N}
#
# Doctext output
section    %n\subhead{%1}%n
s_synopsis %n\subhead{Synopsis}%n\startvb\begin{verbatim}%n%m="verbatim"
e_synopsis %n\end{verbatim}%n\endvb%n%m=""
em_dash    --- 
eop        \endmanpage%n
bop        \startmanpage%n
bof
eof
linebreak  \nextline%n
s_arg      %n\startarg{
s_defn     {
e_defn     }%n
e_arg      }
s_arg_list 
s_arg_inlist      %n\startarg{
s_defn_inlist     {
e_defn_inlist     }%n
e_arg_inlist      }
e_arg_list
s_doctext_verbatim \linebreak
e_doctext_verbatim 
s_caption  \begin{center}\bf
e_caption  \end{center}
picture    \centerline{\epsf{%1}}
# Only do the actual title
mantitle   \mantitle{%1}{%2}{%3}%n\manname{%1}%n
mantitlemany   \mantitle{%1}{%2}{%3}%n\manname{%1}%n
location   %n\location{%1}%n
anchor	   \hypertarget{%1}{}%n