# Here's an alternative to the argument formatting that uses a table
# You can get this by specifying -defn htmlargtbl.def to doctext.
s_arg_list    %n<TABLE BORDER=0>
s_arg_inlist  %n<TR><TD WIDTH=20></TD><TD ALIGN=LEFT VALIGN=TOP><B>
e_arg_inlist  </B></TD>
s_defn_inlist <TD VALIGN=TOP>
# The br is used to break the line in the event that the browser doesn't
# support tables.  It is better than nothing.
e_defn_inlist <BR></TD></TR>
e_arg_list    </TABLE>%n
